require 'spec_helper'
require 'backdrop/api_builder'

describe Backdrop::APIBuilder do
  describe '#build' do
    let(:url) { '/some/location' }
    let(:output_file) { 'tmp/backdrop/some/location.json' }

    context 'when the input is a single item' do
      let(:sample_input) { build :example, backdrop_url: url }
      let(:json) { '{"some":"data"}' }

      it 'writes a JSON file at the URL path' do
        subject.build sample_input
        expect(File.read(output_file)).to eq json
      end
    end

    context 'when the input is an array of items' do
      let(:sample_input) { build_list :example, 2, backdrop_url: url }
      let(:json) { '[{"some":"data"},{"some":"data"}]' }

      it 'writes a JSON file at the URL path' do
        subject.build sample_input
        expect(File.read(output_file)).to eq json
      end
    end

    context 'when the URL is specified' do
      let(:sample_input) { build :example }
      let(:json) { '{"some":"data"}' }

      subject { described_class.new(url) }

      it 'writes a JSON file at the URL path' do
        subject.build sample_input
        expect(File.read(output_file)).to eq json
      end
    end
  end
end
