require 'spec_helper'
require 'backdrop'

describe Backdrop do
  describe '.configure' do
    it 'yields the configuration' do
      Backdrop.configure do |config|
        expect(config).to be_a(Backdrop::Configuration)
      end
    end
  end

  describe '.configuration' do
    it 'returns the current configuration' do
      Backdrop.configure do |config|
        @config = config
      end
      expect(Backdrop.configuration).to eq @config
    end
  end

  describe '.reset' do
    let!(:subject) { Backdrop.configuration }

    it 'resets all configuration' do
      Backdrop.reset
      expect(Backdrop.configuration).to_not eq subject
    end
  end

  describe '.load' do
    let(:input) { %w('some', 'data') }
    let(:builder) { double :builder, build: true }

    before do
      allow(Backdrop::APIBuilder)
        .to receive(:new).and_return builder
    end

    it 'delegates to the Backdrop API Builder' do
      expect(builder).to receive(:build).with input
      described_class.load input
    end

    context 'when the Backdrop URL is specified' do
      it 'delegates with the URL' do
        expect(Backdrop::APIBuilder)
          .to receive(:new).with 'a/url'

        described_class.load input, 'a/url'
      end
    end

    context 'when the Backdrop URL is implicit' do
      it 'delegates with a nil URL' do
        expect(Backdrop::APIBuilder)
          .to receive(:new).with nil

        described_class.load input
      end
    end
  end

  describe '.clear' do
    it 'clears all routes from the web server' do
      expect(Backdrop::App).to receive(:reset!)
      Backdrop.clear
    end
  end
end
