require 'spec_helper'
require 'rack/test'
require 'backdrop'

describe Backdrop do
  include Rack::Test::Methods

  def app
    Backdrop::App
  end

  context 'when the route is implicit' do
    before do
      Backdrop.load sample_factory_data
    end

    context 'when it is a single object' do
      let(:sample_factory_data) { build :example }

      it 'builds an API based on factory girl data' do
        get '/example/data'
        expect(last_response.body).to eq '{"some":"data"}'
      end
    end

    context 'when it is an array of objects' do
      let(:sample_factory_data) { build_list :example, 2 }

      it 'builds an API based on the array of factory girl data' do
        get '/example/data'
        expect(last_response.body).to eq '[{"some":"data"},{"some":"data"}]'
      end
    end
  end

  context 'when the route is explicit' do
    let(:sample_factory_data) { build :example }

    before do
      Backdrop.load sample_factory_data, 'my/custom/url'
    end

    it 'builds an API based on factory girl data' do
      get 'my/custom/url'
      expect(last_response.body).to eq '{"some":"data"}'
    end
  end

  context 'when the route does not exist' do
    let(:sample_factory_data) { build :example }
    it 'gives status 404' do
      get '/nothing'
      expect(last_response.status).to eq 404
    end
  end
end
