require 'coveralls'
require 'simplecov'
require 'codeclimate-test-reporter'

CodeClimate::TestReporter.configure do |config|
  config.logger.level = Logger::WARN
end

formatters = [
  SimpleCov::Formatter::HTMLFormatter,
  Coveralls::SimpleCov::Formatter
]

if ENV['CODECLIMATE_REPO_TOKEN']
  formatters << CodeClimate::TestReporter::Formatter
end

SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[*formatters]
SimpleCov.coverage_dir 'log/coverage/rspec'
SimpleCov.start do
  add_filter 'vendor'
  add_filter 'spec'
end

require 'factory_girl'
FactoryGirl.find_definitions

RSpec.configure do |config|
  config.default_formatter = 'doc' if config.files_to_run.one?
  config.include FactoryGirl::Syntax::Methods

  config.order = :random

  Kernel.srand config.seed

  config.expect_with :rspec do |expectations|
    expectations.syntax = :expect
  end

  config.mock_with :rspec do |mocks|
    mocks.syntax = :expect
    mocks.verify_partial_doubles = true
  end
end
